.highlight button.copybtn
  color: var(--color-foreground-secondary)
  background-color: var(--color-background-secondary)
  border: 1px solid var(--color-background-border)

  &.success
    border-color: #22863a
  &:hover
    color: var(--color-foreground-primary)
    background-color: var(--color-background-primary)

  &::after
    color: var(--color-foreground-secondary)
    background: var(--color-background-primary)
